package name.nathanmcrae.numbersstation;

import com.fasterxml.jackson.databind.ObjectMapper;
import com.fasterxml.jackson.databind.json.JsonMapper;
import com.fasterxml.jackson.databind.SerializationFeature;
import com.fasterxml.jackson.dataformat.xml.XmlMapper;
import com.fasterxml.jackson.datatype.jsr310.JavaTimeModule;
import java.io.File;
import java.io.IOException;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.util.ArrayList;

public class MainSettings {
    private int digitsPerGroup;
    private String username;
    private int refreshInterval;
    private String selectedStationName;

    private ArrayList<StationSettings> stations;

    public MainSettings() {
        stations = new ArrayList<>();
        stations.add(new StationSettings("Station 1"));
    }

    public static Path getSettingsFilePath() {
        String configHome = System.getenv("XDG_CONFIG_HOME");
        Path directoryPath;
        Path filePath;

        if (configHome != null && !configHome.isEmpty()) {
            directoryPath = Paths.get(configHome, "numbers-station");
        } else {
            String userHome = System.getProperty("user.home");
            directoryPath = Paths.get(userHome, ".config", "numbers-station");
        }

        return directoryPath.resolve("main-settings.xml");
    }

    public ArrayList<StationSettings> getStations() {
        return stations;
    }

    public String getUsername() {
        return username;
    }

    public void setUsername(String username) {
        this.username = username;
    }

    public int getRefreshInterval() {
        return refreshInterval;
    }

    public void setRefreshInterval(int refreshInterval) {
        this.refreshInterval = refreshInterval;
    }

    public String getSelectedStationName() {
        return selectedStationName;
    }

    public void setSelectedStationName(String selectedStationName) {
        this.selectedStationName = selectedStationName;
    }

    public void save() {
        XmlMapper xmlMapper = new XmlMapper();
        xmlMapper.registerModule(new JavaTimeModule());
        xmlMapper.configure(SerializationFeature.WRITE_DATES_AS_TIMESTAMPS, false);
        try {
            Path filePath = getSettingsFilePath();
            Path directoryPath = filePath.getParent();

            if (!Files.exists(directoryPath)) {
                Files.createDirectories(directoryPath);
            }

            xmlMapper.writeValue(new File(filePath.toString()), this);
        } catch (IOException e) {
            e.printStackTrace();
        }
    }
}
