package name.nathanmcrae.numbersstation;

import java.time.LocalDate;
import java.time.LocalTime;
import java.util.ArrayList;

public class StationSettings {
    private String address;
    private int digitsPerGroup;
    private String externalProgramCommand;
    private boolean manageScheduleExternally;
    private int messageLength;
    private MessageMethod messageMethod;
    private MessagePeriod messagePeriod;
    private String name;
    private String password;
    private ArrayList<String> prefixes;
    private LocalDate scheduleStartDate;
    private LocalTime scheduleStartTime;
    private String username;

    public enum MessageMethod {
        FTP,
        SFTP,
        SCP,
        EXTERNAL_PROGRAM
    }

    public enum MessagePeriod {
        DAILY,
        WEEKLY,
        MONTHLY
    }

    public StationSettings() {
        prefixes = new ArrayList<String>();
    }

    public StationSettings(String newName) {
        name = newName;
    }

    public String getAddress() {
        return address;
    }

    public void setAddress(String newAddress) {
        address = newAddress;
    }

    public int getDigitsPerGroup() {
        return digitsPerGroup;
    }

    public void setDigitsPerGroup(int newDigitsPerGroup) {
        digitsPerGroup = newDigitsPerGroup;
    }

    public String getExternalProgramCommand() {
        return externalProgramCommand;
    }

    public void setExternalProgramCommand(String newExternalProgramCommand) {
        externalProgramCommand = newExternalProgramCommand;
    }

    public boolean getManageScheduleExternally() {
        return manageScheduleExternally;
    }

    public void setManageScheduleExternally(boolean newManageScheduleExternally) {
        manageScheduleExternally = newManageScheduleExternally;
    }

    public int getMessageLength() {
        return messageLength;
    }

    public void setMessageLength(int newMessageLength) {
        messageLength = newMessageLength;
    }

    public MessageMethod getMessageMethod() {
        return messageMethod;
    }

    public void setMessageMethod(MessageMethod newMessageMethod) {
        messageMethod = newMessageMethod;
    }

    public MessagePeriod getMessagePeriod() {
        return messagePeriod;
    }

    public void setMessagePeriod(MessagePeriod newMessagePeriod) {
        messagePeriod = newMessagePeriod;
    }

    public String getName() {
        return name;
    }

    public void setName(String newName) {
        name = newName;
    }

    public String getPassword() {
        return password;
    }

    public void setPassword(String newPassword) {
        password = newPassword;
    }

    public ArrayList<String> getPrefixes() {
        if (prefixes == null) {
            prefixes = new ArrayList<String>();
        }
        return prefixes;
    }

    public LocalDate getScheduleStartDate() {
        return scheduleStartDate;
    }

    public void setScheduleStartDate(LocalDate newScheduleStartDate) {
        scheduleStartDate = newScheduleStartDate;
    }

    public LocalTime getScheduleStartTime() {
        return scheduleStartTime;
    }

    public void setScheduleStartTime(LocalTime newScheduleStartTime) {
        scheduleStartTime = newScheduleStartTime;
    }

    public String getUsername() {
        return username;
    }

    public void setUsername(String newUsername) {
        username = newUsername;
    }

    @Override
    public String toString() {
        return name;
    }
}
